pyxmpp2.mainloop.interfaces.IOHandlerPrepareResult

Package pyxmpp2 :: Package mainloop :: Module interfaces :: Class IOHandlerPrepareResult |
[hide private]

# Class IOHandlerPrepareResult

Result of the IOHandler.prepare method.

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`